[Libreoffice-commits] core.git: dtrans/source include/filter offapi/com offapi/type_reference sd/source

2017-05-29 Thread Stephan Bergmann
 dtrans/source/win32/clipb/WinClipbImpl.cxx   |4 
+---
 include/filter/msfilter/escherex.hxx |2 +-
 offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl |3 +--
 offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl  |2 +-
 offapi/type_reference/offapi.idl |3 +--
 sd/source/filter/eppt/eppt.cxx   |2 +-
 6 files changed, 6 insertions(+), 10 deletions(-)

New commits:
commit 32260c40b265b97358fc426fb9f849c243dc7dd4
Author: Stephan Bergmann 
Date:   Mon May 29 15:38:06 2017 +0200

Revert "[API-CHANGE] Add persistent (in addition to persistant)"

This reverts commit 795d56dfd55a78a240cef79c822ba958c4f18006.  The Gerrit 
UI had
fooled me into pushing the "Submit" button in error.

diff --git a/dtrans/source/win32/clipb/WinClipbImpl.cxx 
b/dtrans/source/win32/clipb/WinClipbImpl.cxx
index f10050b20817..548a7ff4c5aa 100644
--- a/dtrans/source/win32/clipb/WinClipbImpl.cxx
+++ b/dtrans/source/win32/clipb/WinClipbImpl.cxx
@@ -138,9 +138,7 @@ OUString SAL_CALL CWinClipbImpl::getName(  )
 
 sal_Int8 SAL_CALL CWinClipbImpl::getRenderingCapabilities(  )
 {
-// Errant spelling "Persistant" deprecated in version 5.4
-// see offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
-return ( Delayed | Persistant | Persistent );
+return ( Delayed | Persistant );
 }
 
 void SAL_CALL CWinClipbImpl::flushClipboard( )
diff --git a/include/filter/msfilter/escherex.hxx 
b/include/filter/msfilter/escherex.hxx
index f25a961b7bc3..4486ceb34e58 100644
--- a/include/filter/msfilter/escherex.hxx
+++ b/include/filter/msfilter/escherex.hxx
@@ -1090,7 +1090,7 @@ public:
  */
 voidInsertAtCurrentPos( sal_uInt32 nBytes );
 
-voidInsertPersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
); // It is not being checked if this key is already in the PersistentTable
+voidInsertPersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
); // It is not being checked if this key is already in the PersistantTable
 voidReplacePersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
);
 sal_uInt32  GetPersistOffset( sal_uInt32 nKey );
 boolSeekToPersistOffset( sal_uInt32 nKey );
diff --git 
a/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl 
b/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
index f46bd2ff5d31..6b0cdc96c230 100644
--- a/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
+++ b/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
@@ -37,8 +37,7 @@ published constants RenderingCapabilities
 /** The implementation is able to store the data persistent in the system
 so that it does not get lost when the source application no longer 
exist.
 */
-/** @deprecated */ const byte Persistant = 2;
-const byte Persistent = 2;
+const byte Persistant = 2;
 };
 
 
diff --git a/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl 
b/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
index 32f8bf39db4e..1cb96db1ece8 100644
--- a/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
+++ b/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
@@ -46,7 +46,7 @@ published interface XSystemClipboard
 /** Provides the ability to render the complete clipboard content. This
 interface is only available if the method
 
com::sun::star::datatransfer::clipboard::XClipboardEx::getRenderingCapabilities()
-returns Persistent
+returns Persistant
 */
 [optional] interface XFlushableClipboard;
 
diff --git a/offapi/type_reference/offapi.idl b/offapi/type_reference/offapi.idl
index 14f39fac820d..e796d59192e2 100644
--- a/offapi/type_reference/offapi.idl
+++ b/offapi/type_reference/offapi.idl
@@ -4312,8 +4312,7 @@ module com {
  };
  published constants RenderingCapabilities {
   const byte Delayed = 1;
-  /** @deprecated */ const byte Persistant = 2;
-  const byte Persistent = 2;
+  const byte Persistant = 2;
  };
  published interface XFlushableClipboard {
   interface ::com::sun::star::uno::XInterface;
diff --git a/dtrans/source/win32/clipb/WinClipbImpl.cxx 
b/dtrans/source/win32/clipb/WinClipbImpl.cxx
index 548a7ff4c5aa..f10050b20817 100644
--- a/dtrans/source/win32/clipb/WinClipbImpl.cxx
+++ b/dtrans/source/win32/clipb/WinClipbImpl.cxx
@@ -138,7 +138,9 @@ OUString SAL_CALL CWinClipbImpl::getName(  )
 
 sal_Int8 SAL_CALL CWinClipbImpl::getRenderingCapabilities(  )
 {
-return ( Delayed | Persistant );
+// Errant spelling "Persistant" deprecated in version 5.4
+// see offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
+return ( Delayed | Persistant | Persistent );
 }
 
 void SAL_CALL CWinClipbImpl::flushClipboard( )
diff --git a/include/filter/msfilter/escherex.hxx 
b/include/filter/msfilter/escherex.hxx
index 4486ceb34e58..f25a961b7bc3 100644
--- a/include/filter/msfilter/escherex.hxx
+++ b/include/filter/msfilter/escherex.hxx
@@ -1090,7 +1090,7 @@ public:
  */
 voidInsertAtCurrentPos( sal_uInt32 nBytes );
 
-voidInsertPersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
); // It is not being checked if this key is already in the PersistantTable
+voidInsertPersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
); // It is not being checked if this key is already in the PersistentTable
 voidReplacePersistOffset( sal_uInt32 nKey, sal_uInt32 nOffset 
);
 sal_uInt32  GetPersistOffset( sal_uInt32 nKey );
 boolSeekToPersistOffset( sal_uInt32 nKey );
diff --git 
a/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl 
b/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
index 6b0cdc96c230..f46bd2ff5d31 100644
--- a/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
+++ b/offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl
@@ -37,7 +37,8 @@ published constants RenderingCapabilities
 /** The implementation is able to store the data persistent in the system
 so that it does not get lost when the source application no longer 
exist.
 */
-const byte Persistant = 2;
+/** @deprecated */ const byte Persistant = 2;
+const byte Persistent = 2;
 };
 
 
diff --git a/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl 
b/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
index 1cb96db1ece8..32f8bf39db4e 100644
--- a/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
+++ b/offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl
@@ -46,7 +46,7 @@ published interface XSystemClipboard
 /** Provides the ability to render the complete clipboard content. This
 interface is only available if the method
 
com::sun::star::datatransfer::clipboard::XClipboardEx::getRenderingCapabilities()
-returns Persistant
+returns Persistent
 */
 [optional] interface XFlushableClipboard;
 
diff --git a/offapi/type_reference/offapi.idl b/offapi/type_reference/offapi.idl
index e796d59192e2..14f39fac820d 100644
--- a/offapi/type_reference/offapi.idl
+++ b/offapi/type_reference/offapi.idl
@@ -4312,7 +4312,8 @@ module com {
  };
  published constants RenderingCapabilities {
   const byte Delayed = 1;
-  const byte Persistant = 2;
+  /** @deprecated */ const byte Persistant = 2;
+  const byte Persistent = 2;
  };
  published interface XFlushableClipboard {
   interface ::com::sun::star::uno::XInterface;
diff --git a/sd/source/filter/eppt/eppt.cxx b/sd/source/filter/eppt/eppt.cxx
index fc6dce12a3e5..33f44824691b 100644
--- a/sd/source/filter/eppt/eppt.cxx
+++ b/sd/source/filter/eppt/eppt.cxx
@@ -1319,7 +1319,7 @@ void PPTWriter::ImplWriteOLE( )
 }
 }
 
-// write PersistantTable and UserEditAtom
+// write PersistentTable and UserEditAtom
 
 bool PPTWriter::ImplWriteAtomEnding()
 {
___
Libreoffice-commits mailing list
diff --git a/sd/source/filter/eppt/eppt.cxx b/sd/source/filter/eppt/eppt.cxx
index 33f44824691b..fc6dce12a3e5 100644
--- a/sd/source/filter/eppt/eppt.cxx
+++ b/sd/source/filter/eppt/eppt.cxx
@@ -1319,7 +1319,7 @@ void PPTWriter::ImplWriteOLE( )
 }
 }
 
 // write PersistentTable and UserEditAtom
 
 bool PPTWriter::ImplWriteAtomEnding()
 {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: dtrans/source include/filter offapi/com offapi/type_reference sd/source

2017-05-29 Thread Julien Nabet
 dtrans/source/win32/clipb/WinClipbImpl.cxx   |4 
+++-
 include/filter/msfilter/escherex.hxx |2 +-
 offapi/com/sun/star/datatransfer/clipboard/RenderingCapabilities.idl |3 ++-
 offapi/com/sun/star/datatransfer/clipboard/XSystemClipboard.idl  |2 +-
 offapi/type_reference/offapi.idl |3 ++-
 sd/source/filter/eppt/eppt.cxx   |2 +-
 6 files changed, 10 insertions(+), 6 deletions(-)

New commits:
commit 795d56dfd55a78a240cef79c822ba958c4f18006
Author: Julien Nabet 
Date:   Thu Apr 27 22:22:33 2017 +0200

[API-CHANGE] Add persistent (in addition to persistant)

+ keep "persistant" for compatibility reasons
@@ -1319,7 +1319,7 @@ void PPTWriter::ImplWriteOLE( )
 }
 
-// write PersistentTable and UserEditAtom
+// write PersistantTable and UserEditAtom
 
 bool PPTWriter::ImplWriteAtomEnding()
but put it as deprecated

Change-Id: I7ef8efb9f376eadfdac876d142840aab5a0b4416
Reviewed-on: https://gerrit.libreoffice.org/37042
Tested-by: Jenkins 
Reviewed-by: Michael Meeks 
